@@ -71,6 +71,7 @@ def check_is_site(string):
     ff = hostnames.get('ff')
     nk = hostnames.get('nk')
     ww = hostnames.get('ww')
+    dd = hostnames.get('dd')
 
     string = string.lower()
 
@@ -92,6 +93,8 @@ def check_is_site(string):
         return "NK"
     elif ww and ww.split('.')[0] in string:
         return "WW"
+    elif dd and dd.split('.')[0] in string:
+        return "DD"
     else:
         return False
 
@@ -506,3 +509,19 @@ def site_blocked_with_flaresolverr(url):
         if site and check_against == site and db_status.retrieve(check_against + "_flaresolverr"):
             return True
     return False
+
+
+def simplified_search_term_in_title(search_term, release_title, no_numbers=False):
+    if no_numbers:
+        match_regex = r'[^a-zA-Z\s\-\.]'
+    else:
+        match_regex = r'[^a-zA-Z0-9\s\-\.]'
+
+    def unify(string):
+        return string.lower().replace("ß", "ss").replace("ä", "ae").replace("ö", "oe").replace(
+            "ü", "ue").replace(". ", " ").replace("+", ".").replace(" ", ".").strip()
+
+    search_term = re.sub(match_regex, '', unify(search_term))
+    release_title = re.sub(match_regex, '', unify(release_title))
+
+    return search_term in release_title
