@@ -38,7 +38,7 @@ from urllib.parse import quote
 
 from Cryptodome.Cipher import AES
 
-from feedcrawler.http_handlers.requests import request
+from feedcrawler.http_requests.request_handler import request
 
 BS = 16
 
@@ -51,6 +51,10 @@ class TokenExpiredException(BaseException):
     pass
 
 
+class RequestTimeoutException(BaseException):
+    pass
+
+
 def pad(s):
     return s + ((BS - len(s) % BS) * chr(BS - len(s) % BS)).encode()
 
@@ -761,10 +765,13 @@ class Jddevice:
         else:
             # Direct connection info available, we try to use it.
             for conn in self.__direct_connection_info:
+                connection_ip = conn['conn']['ip']
+                if "172.17." in connection_ip or "127.0.0.1" in connection_ip:
+                    continue
                 if time.time() > conn['cooldown']:
                     # We can use the connection
                     connection = conn['conn']
-                    api = "http://" + connection["ip"] + ":" + str(
+                    api = "http://" + connection_ip + ":" + str(
                         connection["port"])
                     # if self.myjd.request_api("/device/ping", "POST", None, self.__action_url(), api):
                     response = self.myjd.request_api(path, http_action, params,
@@ -1066,9 +1073,9 @@ class Myjdapi:
                 ]
             query = query[0] + "&".join(query[1:])
             try:
-                encrypted_response = request(api + query, timeout=3)
+                encrypted_response = request(api + query, timeout=30)
             except URLError:
-                encrypted_response = request(api + query, timeout=3, verify=False)
+                encrypted_response = request(api + query, timeout=30, verify=False)
                 print(u"Die sichere Verbindung zu MyJDownloader konnte nicht verifiziert werden.")
         else:
             params_request = []
@@ -1103,7 +1110,7 @@ class Myjdapi:
                     },
                     data=encrypted_data,
                     method="POST",
-                    timeout=3)
+                    timeout=30)
             except URLError:
                 try:
                     encrypted_response = request(
@@ -1113,13 +1120,15 @@ class Myjdapi:
                         },
                         data=encrypted_data,
                         method="POST",
-                        timeout=3,
+                        timeout=30,
                         verify=False)
                     print(u"Die sichere Verbindung zu MyJDownloader konnte nicht verifiziert werden.")
                 except URLError:
                     return None
         if encrypted_response.status_code == 403:
             raise TokenExpiredException
+        if encrypted_response.status_code == 503:
+            raise RequestTimeoutException
         if encrypted_response.status_code != 200:
             try:
                 error_msg = json.loads(encrypted_response.text)
