@@ -47,6 +47,7 @@ from feedcrawler.myjd import move_to_downloads
 from feedcrawler.myjd import remove_from_linkgrabber
 from feedcrawler.myjd import reset_in_downloads
 from feedcrawler.myjd import retry_decrypt
+from feedcrawler.myjdapi import TokenExpiredException, RequestTimeoutException
 from feedcrawler.notifiers import notify
 from feedcrawler.search import search
 
@@ -281,6 +282,7 @@ def app_container():
             dj_conf = CrawlerConfig('CustomDJ')
             dd_conf = CrawlerConfig('CustomDD')
             f_conf = CrawlerConfig('CustomF')
+            jf_conf = CrawlerConfig('CustomJF')
             return {
                 "settings": {
                     "general": {
@@ -369,8 +371,10 @@ def app_container():
                         "hoster_fallback": dd_conf.get("hoster_fallback"),
                     },
                     "f": {
-                        "interval": to_int(f_conf.get("interval")),
                         "search": to_int(f_conf.get("search"))
+                    },
+                    "jf": {
+                        "wait_time": to_int(jf_conf.get("wait_time")),
                     }
                 }
             }
@@ -456,12 +460,24 @@ def app_container():
             section.save("k2s", to_str(data['hosters']['k2s']))
 
             section = CrawlerConfig("Ombi")
-            section.save("url", to_str(data['ombi']['url']))
-            section.save("api", to_str(data['ombi']['api']))
+            ombi_url = to_str(data['ombi']['url'])
+            ombi_url = ombi_url[:-1] if ombi_url.endswith('/') else ombi_url
+            ombi_api = to_str(data['ombi']['api'])
+            if not ombi_url or not ombi_api:
+                ombi_url = ""
+                ombi_api = ""
+            section.save("url", ombi_url)
+            section.save("api", ombi_api)
 
             section = CrawlerConfig("Overseerr")
-            section.save("url", to_str(data['overseerr']['url']))
-            section.save("api", to_str(data['overseerr']['api']))
+            overseerr_url = to_str(data['overseerr']['url'])
+            overseerr_url = overseerr_url[:-1] if overseerr_url.endswith('/') else overseerr_url
+            overseerr_api = to_str(data['overseerr']['api'])
+            if not overseerr_url or not overseerr_api:
+                overseerr_url = ""
+                overseerr_api = ""
+            section.save("url", overseerr_url)
+            section.save("api", overseerr_api)
 
             section = CrawlerConfig("ContentAll")
             section.save("quality", to_str(data['mb']['quality']))
@@ -507,15 +523,17 @@ def app_container():
             section.save("hoster_fallback", to_str(data['dd']['hoster_fallback']))
 
             section = CrawlerConfig("CustomF")
-            interval = to_str(data['f']['interval'])
-            if to_int(interval) < 6:
-                interval = '6'
-            section.save("interval", interval)
             search_depth = to_str(data['f']['search'])
             if to_int(search_depth) > 7:
                 search_depth = '7'
             section.save("search", search_depth)
 
+            section = CrawlerConfig("CustomJF")
+            wait_time = to_str(data['jf']['wait_time'])
+            if to_int(wait_time) < 6:
+                wait_time = '6'
+            section.save("wait_time", wait_time)
+
             return "Success"
         except:
             return abort(400, "Failed")
@@ -548,12 +566,12 @@ def app_container():
     def get_crawltimes():
         try:
             crawltimes = FeedDb("crawltimes")
-            next_f_run = False
+            next_jf_run = False
             try:
-                last_f_run = to_float(FeedDb('crawltimes').retrieve("last_f_run"))
-                f_interval = to_float(CrawlerConfig('CustomF').get("interval"))
-                if last_f_run:
-                    next_f_run = last_f_run + 1000 * f_interval * 60 * 60
+                last_jf_run = to_float(FeedDb('crawltimes').retrieve("last_jf_run"))
+                jf_wait_time = to_float(CrawlerConfig('CustomJF').get("wait_time"))
+                if last_jf_run:
+                    next_jf_run = last_jf_run + 1000 * jf_wait_time * 60 * 60
             except:
                 pass
             return {
@@ -563,7 +581,7 @@ def app_container():
                     "end_time": to_float(crawltimes.retrieve("end_time")),
                     "total_time": crawltimes.retrieve("total_time"),
                     "next_start": to_float(crawltimes.retrieve("next_start")),
-                    "next_f_run": next_f_run
+                    "next_jf_run": next_jf_run
                 }
             }
         except:
@@ -601,6 +619,35 @@ def app_container():
             s = ' / '.join(list(filter(None, [sj, sf])))
             f = ' / '.join(list(filter(None, [ff, sf])))
             sjbl = ' / '.join(list(filter(None, [s, bl])))
+            jf = ' / '.join(list(filter(None, [sj, dj, sf, ff])))
+
+            jf_shorthands = []
+            if sj:
+                jf_shorthands.append("SJ")
+            if dj:
+                jf_shorthands.append("DJ")
+            if sf:
+                jf_shorthands.append("SF")
+            if ff:
+                jf_shorthands.append("FF")
+            jf_shorthands = '/'.join(list(filter(None, jf_shorthands)))
+
+            search_shorthands = []
+            if sj:
+                search_shorthands.append("SJ")
+            if dj:
+                search_shorthands.append("DJ")
+            if sf:
+                search_shorthands.append("SF")
+            if by:
+                search_shorthands.append("BY")
+            if fx:
+                search_shorthands.append("FX")
+            if hw:
+                search_shorthands.append("HW")
+            if nk:
+                search_shorthands.append("NK")
+            search_shorthands = '/'.join(list(filter(None, search_shorthands)))
 
             if not fx:
                 fx = "Nicht gesetzt!"
@@ -630,6 +677,9 @@ def app_container():
                 f = "Nicht gesetzt!"
             if not sjbl:
                 sjbl = "Nicht gesetzt!"
+            if not jf:
+                jf = "Nicht gesetzt!"
+
             return {
                 "hostnames": {
                     "sj": sj,
@@ -645,7 +695,10 @@ def app_container():
                     "bl": bl,
                     "s": s,
                     "f": f,
-                    "sjbl": sjbl
+                    "sjbl": sjbl,
+                    "jf": jf,
+                    "jf_shorthands": jf_shorthands,
+                    "search_shorthands": search_shorthands
                 }
             }
         except:
@@ -789,8 +842,15 @@ def app_container():
     @auth_basic(is_authenticated_user)
     def myjd_info():
         try:
-            myjd = get_info()
-            packages_to_decrypt = get_to_decrypt()
+            try:
+                myjd = get_info()
+                packages_to_decrypt = get_to_decrypt()
+            except (TokenExpiredException, RequestTimeoutException):
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return abort(500, "Failed")
+                myjd = get_info()
+                packages_to_decrypt = get_to_decrypt()
             if myjd:
                 return {
                     "downloader_state": myjd[1],
@@ -812,7 +872,13 @@ def app_container():
     @auth_basic(is_authenticated_user)
     def myjd_state():
         try:
-            myjd = get_state()
+            try:
+                myjd = get_state()
+            except (TokenExpiredException, RequestTimeoutException):
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return abort(500, "Failed")
+                myjd = get_state()
             if myjd:
                 return {
                     "downloader_state": myjd[1],
@@ -935,7 +1001,14 @@ def app_container():
     @auth_basic(is_authenticated_user)
     def myjd_start():
         try:
-            if jdownloader_start():
+            try:
+                started = jdownloader_start()
+            except (TokenExpiredException, RequestTimeoutException):
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return abort(500, "Failed")
+                started = jdownloader_start()
+            if started:
                 return "Success"
         except:
             pass
@@ -946,7 +1019,14 @@ def app_container():
     def myjd_pause(bl):
         try:
             bl = json.loads(bl)
-            if jdownloader_pause(bl):
+            try:
+                paused = jdownloader_pause(bl)
+            except (TokenExpiredException, RequestTimeoutException):
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return abort(500, "Failed")
+                paused = jdownloader_pause(bl)
+            if paused:
                 return "Success"
         except:
             pass
@@ -956,7 +1036,14 @@ def app_container():
     @auth_basic(is_authenticated_user)
     def myjd_stop():
         try:
-            if jdownloader_stop():
+            try:
+                stopped = jdownloader_stop()
+            except (TokenExpiredException, RequestTimeoutException):
+                get_device()
+                if not internal.device or not is_device(internal.device):
+                    return abort(500, "Failed")
+                stopped = jdownloader_stop()
+            if stopped:
                 return "Success"
         except:
             pass
@@ -1414,10 +1501,11 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                             "[FeedCrawler Sponsors Helper nicht erfolgreich] - " + name + " (Paket nach 3 Versuchen gelöscht)"])
                     except:
                         print(u"Benachrichtigung konnte nicht versendet werden!")
-                    print(u"[FeedCrawler Sponsors Helper erfolgreich] - " + name)
+                    print(
+                        u"[FeedCrawler Sponsors Helper nicht erfolgreich] - " + name + " (Paket nach 3 Versuchen gelöscht)")
                     return "<script type='text/javascript'>" \
                            "function closeWindow(){window.close()}window.onload=closeWindow;</script>" \
-                           "[FeedCrawler Sponsors Helper erfolgreich] - " + name
+                           "[FeedCrawler Sponsors Helper nicht erfolgreich] - " + name + " (Paket nach 3 Versuchen gelöscht)"
         except:
             pass
         return abort(400, "Failed")
@@ -1434,12 +1522,12 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                        "Block status saved"
             else:
                 hostnames = CrawlerConfig('Hostnames')
-                next_f_run = False
+                next_jf_run = False
                 try:
-                    last_f_run = to_float(FeedDb('crawltimes').retrieve("last_f_run"))
-                    f_interval = to_float(CrawlerConfig('CustomF').get("interval"))
-                    if last_f_run:
-                        next_f_run = last_f_run + 1000 * f_interval * 60 * 60
+                    last_jf_run = to_float(FeedDb('crawltimes').retrieve("last_jf_run"))
+                    jf_wait_time = int(CrawlerConfig('CustomJF').get('wait_time'))
+                    if last_jf_run:
+                        next_jf_run = last_jf_run + 1000 * jf_wait_time * 60 * 60
                 except:
                     pass
                 return {
@@ -1447,7 +1535,7 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                         "sf_ff": check("SF_FF", db_status),
                         "sf_hostname": hostnames.get('sf'),
                         "ff_hostname": hostnames.get('ff'),
-                        "next_f_run": next_f_run
+                        "next_jf_run": next_jf_run
                     }
                 }
         except:
@@ -1532,7 +1620,7 @@ if (cnlAllowed && document.getElementsByClassName("cnlform").length) {
                             season_string = "^unmatchable$"
                         try:
                             packages = get_packages_in_linkgrabber()
-                        except feedcrawler.myjdapi.TokenExpiredException:
+                        except (TokenExpiredException, RequestTimeoutException):
                             get_device()
                             if not internal.device or not is_device(internal.device):
                                 return abort(500, "Failed")
